==> sdd.debin-jar-0.2.20-sources.jar: ar/com/sdd/debin/io/QuitarVendedorResponse.java <==
package ar.com.sdd.debin.io;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

@JsonIgnoreProperties(ignoreUnknown=true)
@JsonInclude(JsonInclude.Include.NON_NULL)
public class QuitarVendedorResponse {

    private String descripcion;
    /**
     00: Ok
     82: Entidad Incorrecta
     24: Vendedor inexistente
     99: Error de Sistema
     76: CUIT mal formulado
     74: CBU mal formulado
     */
    private String codigo;

    public QuitarVendedorResponse() {
    }

    public String getDescripcion() {
        return descripcion;
    }

    public void setDescripcion(String descripcion) {
        this.descripcion = descripcion;
    }

    public String getCodigo() {
        return codigo;
    }

    public void setCodigo(String codigo) {
        this.codigo = codigo;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        QuitarVendedorResponse that = (QuitarVendedorResponse) o;

        if (descripcion != null ? !descripcion.equals(that.descripcion) : that.descripcion != null) return false;
        return codigo != null ? codigo.equals(that.codigo) : that.codigo == null;
    }

    @Override
    public int hashCode() {
        int result = descripcion != null ? descripcion.hashCode() : 0;
        result = 31 * result + (codigo != null ? codigo.hashCode() : 0);
        return result;
    }

    @Override
    public String toString() {
        return "QuitarVendedorResponse [" +
                "descripcion=" + descripcion +
                ", codigo=" + codigo +
                ']';
    }
}

==> sdd.debin-jar-0.2.21-sources.jar: ar/com/sdd/debin/io/QuitarVendedorResponse.java <==
package ar.com.sdd.debin.io;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import javax.json.bind.annotation.JsonbNillable;

@JsonIgnoreProperties(ignoreUnknown=true)
@JsonbNillable
public class QuitarVendedorResponse {

    private String descripcion;
    /**
     00: Ok
     82: Entidad Incorrecta
     24: Vendedor inexistente
     99: Error de Sistema
     76: CUIT mal formulado
     74: CBU mal formulado
     */
    private String codigo;

    public QuitarVendedorResponse() {
    }

    public String getDescripcion() {
        return descripcion;
    }

    public void setDescripcion(String descripcion) {
        this.descripcion = descripcion;
    }

    public String getCodigo() {
        return codigo;
    }

    public void setCodigo(String codigo) {
        this.codigo = codigo;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;

        QuitarVendedorResponse that = (QuitarVendedorResponse) o;

        if (descripcion != null ? !descripcion.equals(that.descripcion) : that.descripcion != null) return false;
        return codigo != null ? codigo.equals(that.codigo) : that.codigo == null;
    }

    @Override
    public int hashCode() {
        int result = descripcion != null ? descripcion.hashCode() : 0;
        result = 31 * result + (codigo != null ? codigo.hashCode() : 0);
        return result;
    }

    @Override
    public String toString() {
        return "QuitarVendedorResponse [" +
                "descripcion=" + descripcion +
                ", codigo=" + codigo +
                ']';
    }
}
